import { r as registerInstance, h, H as Host } from './index-1bb5a77c.js';

function gen(name, mods) {
  if (!mods) {
    return '';
  }
  if (typeof mods === 'string') {
    return ` ${name}--${mods}`;
  }
  if (Array.isArray(mods)) {
    return mods.reduce((ret, item) => ret + gen(name, item), '');
  }
  return Object.keys(mods).reduce((ret, key) => ret + (mods[key] ? gen(name, key) : ''), '');
}
function createBEM(name) {
  return function (el, mods) {
    if (el && typeof el !== 'string') {
      mods = el;
      el = '';
    }
    el = el ? `${name}__${el}` : name;
    const className = `${el}${gen(el, mods)}`;
    return getClassMap(className);
  };
}
const getClassList = (classes) => {
  if (classes !== undefined) {
    const array = Array.isArray(classes) ? classes : classes.split(' ');
    return array
      .filter(c => c != null)
      .map(c => c.trim())
      .filter(c => c !== '');
  }
  return [];
};
const getClassMap = (classes) => {
  const map = {};
  getClassList(classes).forEach(c => map[c] = true);
  return map;
};

function createNamespace(name) {
  const prefixedName = `van-${name}`;
  return [
    createBEM(prefixedName),
  ];
}

function isDef(val) {
  return val !== undefined && val !== null;
}
function isNumeric(val) {
  return typeof val === 'number' || /^\d+(\.\d+)?$/.test(val);
}

function addUnit(value) {
  if (!isDef(value)) {
    return undefined;
  }
  return isNumeric(value) ? `${value}px` : String(value);
}
function getSizeStyle(originSize) {
  if (isDef(originSize)) {
    const size = addUnit(originSize);
    return {
      width: size,
      height: size,
    };
  }
}

const zanSkeletonCss = ":root{--van-skeleton-row-height:16px;--van-skeleton-row-background-color:var(--van-active-color);--van-skeleton-row-margin-top:var(--van-padding-sm);--van-skeleton-title-width:40%;--van-skeleton-avatar-size:32px;--van-skeleton-avatar-background-color:var(--van-active-color);--van-skeleton-animation-duration:1.2s}.van-skeleton{display:flex;padding:0 var(--van-padding-md)}.van-skeleton__avatar{flex-shrink:0;width:var(--van-skeleton-avatar-size);height:var(--van-skeleton-avatar-size);margin-right:var(--van-padding-md);background-color:var(--van-skeleton-avatar-background-color)}.van-skeleton__avatar--round{border-radius:var(--van-border-radius-max)}.van-skeleton__content{width:100%}.van-skeleton__avatar+.van-skeleton__content{padding-top:var(--van-padding-xs)}.van-skeleton__row,.van-skeleton__title{height:var(--van-skeleton-row-height);background-color:var(--van-skeleton-row-background-color)}.van-skeleton__title{width:var(--van-skeleton-title-width);margin:0}.van-skeleton__row:not(:first-child){margin-top:var(--van-skeleton-row-margin-top)}.van-skeleton__title+.van-skeleton__row{margin-top:20px}.van-skeleton--animate{animation:van-skeleton-blink var(--van-skeleton-animation-duration) ease-in-out infinite}.van-skeleton--round .van-skeleton__row,.van-skeleton--round .van-skeleton__title{border-radius:var(--van-border-radius-max)}@keyframes van-skeleton-blink{50%{opacity:0.6}}";

const [bem] = createNamespace('skeleton');
const DEFAULT_ROW_WIDTH = '100%';
const DEFAULT_LAST_ROW_WIDTH = '60%';
const ZanSkeleton = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /**
     * 段落占位图行数
     */
    this.row = 0;
    /**
     * 段落占位图宽度，可传数组来设置每一行的宽度
     */
    this.rowWidth = DEFAULT_ROW_WIDTH;
    /**
     * 是否显示标题占位图
     */
    this.showTitle = false;
    /**
     * 是否显示头像占位图
     */
    this.showAvatar = false;
    /**
     * 是否显示骨架屏，传 false 时会展示子组件内容
     */
    this.loading = false;
    /**
     * 是否开启动画
     */
    this.showAnimate = false;
    /**
     * 是否将标题和段落显示为圆角风格
     */
    this.round = false;
    /**
     * 标题占位图宽度
     */
    this.titleWidth = '40%';
    /**
     * 头像占位图大小
     */
    this.avatarSize = '32px';
    /**
     * 头像占位图形状，可选值为 square
     */
    this.avatarShape = 'round';
    this.renderAvatar = () => {
      if (this.showAvatar) {
        return (h("div", { class: bem('avatar', this.avatarShape), style: getSizeStyle(this.avatarSize) }));
      }
    };
    this.renderTitle = () => {
      if (this.showTitle) {
        return (h("h3", { class: bem('title'), style: { width: addUnit(this.titleWidth) } }));
      }
    };
    this.getRowWidth = (index) => {
      const rowWidth = this.rowWidth;
      if (rowWidth === DEFAULT_ROW_WIDTH && index === +this.row - 1) {
        return DEFAULT_LAST_ROW_WIDTH;
      }
      if (Array.isArray(rowWidth)) {
        return rowWidth[index];
      }
      return rowWidth;
    };
    this.renderRows = () => Array(this.row)
      .fill('')
      .map((_, i) => (h("div", { class: bem('row'), style: { width: addUnit(this.getRowWidth(i)) } })));
  }
  render() {
    if (!this.loading) {
      return (h("slot", null));
    }
    return (h(Host, { class: bem({ animate: this.showAnimate, round: this.round }) }, this.renderAvatar(), h("div", { class: bem('content') }, this.renderTitle(), this.renderRows())));
  }
};
ZanSkeleton.style = zanSkeletonCss;

export { ZanSkeleton as zan_skeleton };
